notifications library

Classes

InAppBanner
A non-intrusive in-app notification banner that slides in from the top or bottom and auto-dismisses after displayDuration.
InAppBannerConfig
Configuration object passed to InAppBannerService.show.
InAppBannerService
A service for imperatively showing and hiding InAppBanners.
LocalNotifier
No-op LocalNotifier stub for platforms that do not support flutter_local_notifications (Windows, Linux).
NotificationChannel
Describes an Android notification channel.
NotificationPreferences
Per-user notification preference management.
NotificationTap
Delivered when the user taps a local notification.
PendingNotification
A pending scheduled notification.

Enums

InAppBannerPosition
Controls where the InAppBanner slides in from.
PkNotificationImportance
Controls how prominently a notification is displayed.