AuthException class final
Thrown for authentication-related failures.
- Inheritance
-
- Object
- PrimekitException
- AuthException
- Implementers
Constructors
- AuthException({required String message, String? code, Object? cause})
-
const
Properties
- cause → Object?
-
The underlying exception that caused this error, if any.
finalinherited
- code → String?
-
Optional machine-readable error code.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Developer-facing error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userMessage → String
-
A safe, user-facing message (defaults to generic message).
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited