EmailProvider class abstract

The common interface all email providers must implement.

Implement this to add a custom email provider:

class MailgunProvider implements EmailProvider {
  @override
  String get name => 'Mailgun';

  @override
  Future<EmailResult> send(EmailMessage message) async { ... }
}
Implementers

Constructors

EmailProvider()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The human-readable provider name (e.g. 'SendGrid').
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(EmailMessage message) Future<EmailResult>
Sends message and returns an EmailResult.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited