EmailResult class sealed

The result of an email send attempt.

Implementers

Constructors

EmailResult.failure({required String reason, int? statusCode})
Creates a failure result with a human-readable reason and optional HTTP statusCode.
const
factory
EmailResult.success({required String messageId})
Creates a successful send result with the provider's messageId.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isFailure bool
Returns true if the send attempt failed.
no setter
isSuccess bool
Returns true if the email was sent successfully.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<T>({required T success(EmailSuccess result), required T failure(EmailFailure result)}) → T
Exhaustively maps this result to a value of type T.

Operators

operator ==(Object other) bool
The equality operator.
inherited