EmailSuccess class final
The success variant of EmailResult.
- Inheritance
-
- Object
- EmailResult
- EmailSuccess
Constructors
- EmailSuccess({required String messageId})
-
Creates a successful email result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isFailure → bool
-
Returns
trueif the send attempt failed.no setterinherited - isSuccess → bool
-
Returns
trueif the email was sent successfully.no setterinherited - messageId → String
-
The message ID returned by the email provider.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
when<
T> ({required T success(EmailSuccess result), required T failure(EmailFailure result)}) → T -
Exhaustively maps this result to a value of type
T.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override