EntitlementLoading class final

The entitlement system has not yet completed initialisation.

Inheritance

Constructors

EntitlementLoading()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isAllowed bool
Convenience: true only for EntitlementAllowed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited