FlushCompletedEvent class final

Emitted when a flush cycle completes.

Inheritance

Constructors

FlushCompletedEvent({required int succeeded, required int dropped})
const

Properties

dropped int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
succeeded int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited