FunnelDefinition class final

Defines a named multi-step user funnel.

const onboarding = FunnelDefinition(
  name: 'onboarding',
  steps: [
    'welcome', 'profile_setup', 'notification_permission', 'complete',
  ],
);

Constructors

FunnelDefinition({required String name, required List<String> steps})
Creates an immutable funnel definition.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Unique identifier for this funnel.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<String>
Ordered list of step names. Steps must be completed in order.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited