MemberBadge class

A visual chip/tag that displays a user's MembershipTier.

The badge renders the tier's MembershipTier.badgeLabel and uses the tier's MembershipTier.badgeColor as its background. Nothing is rendered for tiers with no MembershipTier.badgeLabel.

MemberBadge(
  tier: MembershipTier.pro,
  size: MemberBadgeSize.medium,
  showIcon: true,
)
Inheritance

Constructors

MemberBadge({required MembershipTier tier, Key? key, MemberBadgeSize size = MemberBadgeSize.medium, bool showIcon = true})
Creates a MemberBadge for tier.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIcon bool
Whether to show a star icon alongside the tier label.
final
size MemberBadgeSize
Controls the visual size of the badge.
final
tier MembershipTier
The membership tier to display.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited