MemberBadgeSize enum

The display size of a MemberBadge.

Inheritance
Available extensions

Values

small → const MemberBadgeSize

Compact badge — suitable for list items and avatars.

medium → const MemberBadgeSize

Standard badge — suitable for profile pages and cards.

large → const MemberBadgeSize

Large badge — suitable for prominent tier-display areas.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MemberBadgeSize>
A constant List of the values in this enum, in order of their declaration.