NetworkSyncTask class final
Flushes the OfflineQueue when a network connection is available.
Scheduled periodically to drain any requests that were enqueued while the device was offline.
- Implemented types
Constructors
- NetworkSyncTask()
- Creates a NetworkSyncTask instance.
Properties
Methods
-
execute(
Map< String, dynamic> inputData) → Future<bool> -
Executes the task body with the given
inputData.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited