OtpValidationResult enum

The outcome of an OtpService.validate call.

Inheritance
Available extensions

Values

valid → const OtpValidationResult

The code matched and was not expired.

expired → const OtpValidationResult

The entry's TTL has passed.

invalid → const OtpValidationResult

The code did not match.

maxAttemptsReached → const OtpValidationResult

The maximum number of allowed attempts was reached.

notFound → const OtpValidationResult

No OTP was found for the given key.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OtpValidationResult>
A constant List of the values in this enum, in order of their declaration.