PkUiTheme class
ThemeExtension for PrimeKit UI components. Add to your ThemeData to customize PrimeKit colors:
theme: ThemeData(
extensions: [
PkUiTheme(
successColor: Color(0xFF2E7D32),
errorColor: Color(0xFFC62828),
),
],
)
- Inheritance
-
- Object
- ThemeExtension<
PkUiTheme> - PkUiTheme
Constructors
Properties
- effectiveErrorColor → Color
-
no setter
- effectiveInfoColor → Color
-
no setter
- effectiveLoadingBarrierColor → Color
-
no setter
- effectiveSkeletonBaseColor → Color
-
no setter
- effectiveSkeletonHighlightColor → Color
-
no setter
- effectiveSuccessColor → Color
-
no setter
- effectiveToastTextColor → Color
-
no setter
- effectiveWarningColor → Color
-
no setter
- errorColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- infoColor → Color?
-
final
- loadingBarrierColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skeletonBaseColor → Color?
-
final
- skeletonHighlightColor → Color?
-
final
- successColor → Color?
-
final
- toastTextColor → Color?
-
final
- type → Object
-
The extension's type.
no setterinherited
- warningColor → Color?
-
final
Methods
-
copyWith(
{Color? successColor, Color? errorColor, Color? warningColor, Color? infoColor, Color? toastTextColor, Color? loadingBarrierColor, Color? skeletonBaseColor, Color? skeletonHighlightColor}) → PkUiTheme -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant PkUiTheme? other, double t) → PkUiTheme -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → PkUiTheme?