PurchaseFailed class final
A purchase attempt failed.
- Inheritance
-
- Object
- BillingEvent
- PurchaseFailed
Constructors
- PurchaseFailed({required String productId, required String reason})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- productId → String
-
The Primekit product ID for which the purchase was attempted.
final
- reason → String
-
A developer-readable reason string describing the failure.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override