RequestDroppedEvent class final

Emitted when a request fails after exhausting its retry budget.

Inheritance

Constructors

RequestDroppedEvent(QueuedRequest request, PrimekitException error)
const

Properties

error PrimekitException
final
hashCode int
The hash code for this object.
no setterinherited
request QueuedRequest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited