ResendProvider class

Sends emails via the Resend API.

Required dependency: dio (already in pubspec).

EmailService.instance.configure(
  provider: ResendProvider(
    apiKey: Env.resendApiKey,
    fromEmail: 'noreply@example.com',
  ),
);
Implemented types

Constructors

ResendProvider({required String apiKey, required String fromEmail})
Creates a Resend email provider.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The human-readable provider name (e.g. 'SendGrid').
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(EmailMessage message) Future<EmailResult>
Sends message and returns an EmailResult.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited