RewardItem class final

A reward item returned by a rewarded ad.

Constructors

RewardItem({required String type, required int amount})
const

Properties

amount int
Reward amount.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Reward type string returned by the SDK (e.g. 'coins').
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited