firebase library

Firebase adapters — import this file in addition to primekit.dart to use Firebase-backed implementations.

This replaces the old package:primekit_firebase/primekit_firebase.dart import.

Classes

ActivityFeedSource
Abstract backend for fetching and publishing activity feed items.
FirebaseActivityFeedSource
ActivityFeedSource backed by Cloud Firestore.
FirebaseAuthInterceptor
A ready-to-use AuthInterceptor for Firebase Auth apps.
FirebaseCrashReporter
Firebase Crashlytics-backed CrashReporter.
FirebaseFlagProvider
A FlagProvider backed by Firebase Remote Config.
FirebaseFollowSource
FollowDataSource backed by Cloud Firestore.
FirebasePresenceService
Firebase RTDB-backed PresenceService.
FirebaseProfileSource
ProfileDataSource backed by Cloud Firestore.
FirebaseRbacProvider
RbacProvider implementation backed by Cloud Firestore and Firebase Auth.
FirebaseRtdbChannel
Firebase Realtime Database implementation of RealtimeChannel.
FirebaseSocialAuth
SocialAuthService backed by Firebase Auth.
FirebaseStorageUploader
MediaUploader implementation backed by Firebase Cloud Storage.
FirestoreCurrencyRateSource
Firestore-backed CurrencyRateSource that reads exchange rates from a Firestore collection and falls back to the HTTP API on failure.
FirestoreSyncSource
A SyncDataSource backed by Google Cloud Firestore.
FollowDataSource
Abstract backend for follow/unfollow operations.
ProfileDataSource
Abstract backend for user profile persistence.
PushHandler
Handles FCM / APNs push messages using firebase_messaging.
PushMessage
A normalised push notification message received from FCM / APNs.