FirebaseAuthInterceptor class
A ready-to-use AuthInterceptor for Firebase Auth apps.
Automatically injects Firebase ID tokens and refreshes them when expired.
final client = PrimekitNetworkClient(
baseUrl: 'https://api.example.com',
interceptors: [FirebaseAuthInterceptor()],
);
- Inheritance
-
- Object
- AuthInterceptor
- FirebaseAuthInterceptor
Constructors
- FirebaseAuthInterceptor({TokenStore? tokenStore, void onSessionExpired()?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → Future< void> -
Called when an exception was occurred during the request.
inherited
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → Future< void> -
Called when the request is about to be sent.
inherited
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void -
Called when the response is about to be resolved.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
initialised(
{void onSessionExpired()?}) → Future< FirebaseAuthInterceptor> - Creates a FirebaseAuthInterceptor that populates the token store from the current Firebase user on initialisation.