watchProfile method
Returns a stream that emits the raw profile map whenever it changes.
Implementation
@override
Stream<Map<String, dynamic>?> watchProfile(String userId) =>
_docRef(userId).snapshots().map((s) => s.exists ? s.data() : null);
Returns a stream that emits the raw profile map whenever it changes.
@override
Stream<Map<String, dynamic>?> watchProfile(String userId) =>
_docRef(userId).snapshots().map((s) => s.exists ? s.data() : null);