simulateOpenedApp method
Simulates the user tapping a notification to open the app.
Implementation
@visibleForTesting
void simulateOpenedApp(PushMessage message) {
_onMessageOpenedApp?.call(message);
}
Simulates the user tapping a notification to open the app.
@visibleForTesting
void simulateOpenedApp(PushMessage message) {
_onMessageOpenedApp?.call(message);
}