PushMessage class final

A normalised push notification message received from FCM / APNs.

Constructors

PushMessage({String? title, String? body, Map<String, dynamic> data = const {}, String? collapseKey, String? messageId})
const

Properties

body String?
Notification body from the payload.
final
collapseKey String?
Collapse key (Android) used to replace similar pending messages.
final
data Map<String, dynamic>
Arbitrary data map attached to the message.
final
hashCode int
The hash code for this object.
no setterinherited
messageId String?
Unique message identifier assigned by FCM.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Notification title from the payload.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited