PkAsyncNotifierMixin<T> mixin

A base class for Riverpod AsyncNotifiers with built-in loading/error/success lifecycle and PrimeKit's Result pattern.

@riverpod
class UserNotifier extends _$UserNotifier with PkAsyncNotifierMixin<User> {
  @override
  Future<User> build() => fetchUser();

  Future<void> refresh() => guard(() => fetchUser());
}

Properties

currentData → T?
Returns the current data, or null if loading (without preserve), error, or not yet loaded.
no setter
currentError Object?
Returns the current error, or null.
no setter
future Future<T>
Obtains a Future that resolves with the first state value that is not AsyncLoading.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
Returns true if this notifier is currently loading.
no setter
ref → AsyncNotifierProviderRef<T>
The Ref from the provider associated with this AsyncNotifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ↔ AsyncValue<T>
The value currently exposed by this AsyncNotifier.
getter/setter pairinherited

Methods

build() FutureOr<T>
Initialize an AsyncNotifier.
inherited
guard(Future<T> operation(), {bool preserveData = true}) Future<void>
Executes operation, setting state to loading, then success or error. Preserves previous data during refresh when preserveData is true.
listenSelf(void listener(AsyncValue<T>? previous, AsyncValue<T> next), {void onError(Object error, StackTrace stackTrace)?}) → void
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(FutureOr<T> cb(T), {FutureOr<T> onError(Object err, StackTrace stackTrace)?}) Future<T>
A function to update state from its previous value, while abstracting loading/error cases for state.
inherited
updateShouldNotify(AsyncValue<T> previous, AsyncValue<T> next) bool
A method invoked when the state exposed by this AsyncNotifier changes.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited