PkAutoDisposeAsyncNotifierMixin<T> mixin
A base class for Riverpod AutoDisposeAsyncNotifiers.
Properties
- currentData → T?
-
no setter
-
future
→ Future<
T> -
Obtains a Future that resolves with the first
statevalue that is notAsyncLoading.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
no setter
-
ref
→ AutoDisposeAsyncNotifierProviderRef<
T> -
The
Reffrom the provider associated with thisAsyncNotifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ AsyncValue<
T> -
The value currently exposed by this
AsyncNotifier.getter/setter pairinherited
Methods
-
build(
) → FutureOr< T> -
Initialize an
AsyncNotifier.inherited -
guard(
Future< T> operation(), {bool preserveData = true}) → Future<void> -
listenSelf(
void listener(AsyncValue< T> ? previous, AsyncValue<T> next), {void onError(Object error, StackTrace stackTrace)?}) → void -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
FutureOr< T> cb(T), {FutureOr<T> onError(Object err, StackTrace stackTrace)?}) → Future<T> -
A function to update
statefrom its previous value, while abstracting loading/error cases forstate.inherited -
updateShouldNotify(
AsyncValue< T> previous, AsyncValue<T> next) → bool -
A method invoked when the state exposed by this
AsyncNotifierchanges.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited