device library

Classes

AppVersion
Provides cached access to the application's version metadata and helpers for update checks.
BiometricAuth
No-op BiometricAuth stub for platforms that do not support local_auth (Linux and other unsupported platforms).
ClipboardHelper
Static helpers for reading and writing the system clipboard.
DeviceDetails
Immutable snapshot of device hardware and OS information.
DeviceInfo
Singleton that provides device hardware and OS information.
VersionInfo
Immutable snapshot of the application version metadata.

Enums

BiometricResult
The outcome of a biometric authentication attempt.
BiometricType
The types of biometric authentication supported by the device.