BoolFlag class final
A FeatureFlag typed to bool.
- Inheritance
-
- Object
- FeatureFlag<
bool> - BoolFlag
Constructors
Properties
- defaultValue → bool
-
Value returned when the flag is not found in the provider.
finalinherited
- description → String?
-
Optional human-readable description of what this flag controls.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBool → bool
-
Returns
truewhenTis bool.no setterinherited - isDouble → bool
-
Returns
truewhenTis double.no setterinherited - isInt → bool
-
Returns
truewhenTis int.no setterinherited - isString → bool
-
Returns
truewhenTis String.no setterinherited - key → String
-
The unique remote config / flag key.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited