BufferedMessage class final
An immutable snapshot of a buffered outgoing message.
- Annotations
Constructors
-
BufferedMessage({required String id, required Map<
String, dynamic> payload, required DateTime queuedAt, String? type}) -
Creates a BufferedMessage.
const
-
BufferedMessage.fromJson(Map<
String, dynamic> json) -
Deserialises a BufferedMessage from a JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this buffered message.
final
-
payload
→ Map<
String, dynamic> -
The outgoing payload.
final
- queuedAt → DateTime
-
When this message was enqueued.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Optional message type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialises this message to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited