EmailResult class sealed
The result of an email send attempt.
- Implementers
Constructors
- EmailResult.failure({required String reason, int? statusCode})
-
Creates a failure result with a human-readable
reasonand optional HTTPstatusCode.constfactory - EmailResult.success({required String messageId})
-
Creates a successful send result with the provider's
messageId.constfactory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
T> ({required T success(EmailSuccess result), required T failure(EmailFailure result)}) → T -
Exhaustively maps this result to a value of type
T.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited