No-op ImageCompressor stub for platforms that do not support
flutter_image_compress (Web, Windows, Linux).
All methods return the original MediaFile unchanged with a debug warning.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
compress(
MediaFile source, {int quality = 85, int? maxWidth, int? maxHeight, CompressFormat format = CompressFormat.jpeg}) → Future< MediaFile> -
Returns
sourceunchanged — image compression is not available on this platform. -
compressToSize(
MediaFile source, {required int targetSizeKb, int minQuality = 40}) → Future< MediaFile> -
Returns
sourceunchanged — image compression is not available on this platform. -
getDimensions(
String path) → Future< ({int height, int width})> -
Always returns
(width: 0, height: 0)on this platform.