PendingNotification class final
A pending scheduled notification.
Constructors
Properties
- body → String
-
Notification body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
The notification ID.
final
- payload → String?
-
Optional payload string.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduledAt → DateTime?
-
When the notification is scheduled to fire.
nullfor repeating ones where the next fire time is computed by the OS.final - title → String
-
Notification title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited