SessionAuthenticated class final
The user is authenticated.
- Inheritance
-
- Object
- SessionState
- SessionAuthenticated
Constructors
-
SessionAuthenticated({required String userId, Map<
String, dynamic> ? userData}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userData
→ Map<
String, dynamic> ? -
Optional arbitrary user profile data returned from the auth provider.
final
- userId → String
-
The authenticated user's identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited