FirebaseProfileSource class final
ProfileDataSource backed by Cloud Firestore.
User documents are stored in a Firestore collection with the user's
UID as the document ID.
- Implemented types
Constructors
- FirebaseProfileSource({FirebaseFirestore? firestore, String collection = 'users'})
- Creates a FirebaseProfileSource.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchProfile(
String userId) → Future< Map< String, dynamic> ?> -
Fetches the raw profile map for
userId, ornullif not found.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateProfile(
String userId, Map< String, dynamic> data) → Future<void> -
Persists
dataforuserId(merge-update semantics).override -
watchProfile(
String userId) → Stream< Map< String, dynamic> ?> -
Returns a stream that emits the raw profile map whenever it changes.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited