storage library
Classes
- AppPreferences
-
A typed
SharedPreferenceswrapper for common application settings. - JsonCache
-
A TTL-based JSON cache backed by
SharedPreferences. - Migration
- Represents a single versioned data migration.
- MigrationRecord
- An immutable record of a migration that has been applied.
- MigrationRunner
- Runs pending data migrations in version order.
- MigrationStore
- Persists the list of executed MigrationRecords.
- SecurePrefs
-
A typed, singleton wrapper around
FlutterSecureStoragethat provides convenience methods for storing primitive and JSON values securely. - SecurePrefsBase
- Abstract interface for secure key-value persistence.
-
The default MigrationStore backed by
SharedPreferences.